package cn.estsh.i3plus.ext.mes.apiservice.controller.report;

import cn.estsh.i3plus.ext.mes.api.base.IMesProductionRecordService;
import cn.estsh.i3plus.ext.mes.api.busi.report.IMesYfReportService;
import cn.estsh.i3plus.ext.mes.apiservice.config.AuthUtilExt;
import cn.estsh.i3plus.ext.mes.pojo.constant.MesCommonConstant;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.mes.bean.MesProduceSn;
import cn.estsh.i3plus.pojo.mes.bean.MesProductionRecord;
import cn.estsh.i3plus.pojo.mes.model.MesProductionRecordModel;
import cn.estsh.impp.framework.base.controller.MesBaseController;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Description : Mes业务报表
 * @Reference :
 * @Author : junsheng.li
 * @CreateDate 2024/6/28 14:17
 * @Modify:
 **/
@Api("Mes业务报表")
@RestController
@RequestMapping(MesCommonConstant.MES_YANFEN + "/report")
public class MesBusiReportController extends MesBaseController {

    @Autowired
    private IMesYfReportService mesYfReportService;

    @Autowired
    private IMesProductionRecordService mesProductionRecordService;

    @ApiOperation(value = "查询追溯报表", notes = "查询追溯报表")
    @GetMapping("/traceability/find")
    public ResultBean findTraceabilityReport(MesProduceSn mesProduceSn) {
        try {
            ValidatorBean.beginValid(mesProduceSn).notNull("productSn", mesProduceSn.getProductSn());
            mesProduceSn.setOrganizeCode(AuthUtilExt.getOrganizeCode());
            return ResultBean.success("查询成功").setResultList(mesYfReportService.findTraceabilityReport(mesProduceSn));
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "零件条码状态查询", notes = "零件条码状态查询")
    @GetMapping("/mesProduceSn/query")
    public ResultBean queryMesProduceSn(MesProduceSn mesProduceSn, Pager pager) {
        try {
            return ResultBean.success("查询成功").setListPager(mesYfReportService.queryMesProduceSn(mesProduceSn,pager));
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }


    @ApiOperation(value = "产品加工记录", notes = "产品加工记录")
    @GetMapping("/mesProductionRecord/query")
    public ResultBean queryMesProductionRecord(MesProductionRecord mesProductionRecord, Pager pager) {
        try {
            return ResultBean.success("查询成功").setListPager(mesYfReportService.queryMesProductionRecord(mesProductionRecord,pager));
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "线边库存报表", notes = "线边库存报表")
    @GetMapping("/mesProductionOffLine/query")
    public ResultBean queryMesProductionOffLine(MesProductionRecordModel mesProductionRecordModel, Pager pager) {
        try {
            ValidatorBean.beginValid(mesProductionRecordModel)
                    .notNull("partNo", mesProductionRecordModel.getPartNo())
                    .notNull("organizeCode", mesProductionRecordModel.getOrganizeCode())
                    .notNull("onLineWorkCellCode",mesProductionRecordModel.getOnLineWorkCellCode())
                    .notNull("offLineWorkCellCode",mesProductionRecordModel.getOffLineWorkCellCode())
                    .notNull("createDateTimeStart",mesProductionRecordModel.getCreateDateTimeStart())
                    .notNull("createDateTimeEnd",mesProductionRecordModel.getCreateDateTimeEnd());
            return ResultBean.success("查询成功").setListPager(mesProductionRecordService.queryMesProductionOffLine(mesProductionRecordModel,pager));
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }
}
